##  Business Context Fact Sheet Subtypes
There are four fact sheet subtypes available (plus one optional subtype) that you can choose from, which gives you the flexibility to align with the most common ways your organization typically structures its business and tasks:
  * Business product: Business products represent all the products or services a company offers to customers.
Example: Life insurance
  * Customer journey: Customer journeys represent the complete lifecycle of a customer's interactions and experiences with the company. They reflect the experience from a customer's point of view.
Example: Career Development Framework / Online Purchase Journey
  * Process: Processes show the different steps and interactions to achieve a specific task; they represent operational activities and workflows within the organization (and are more granular than value streams).
In SAP LeanIX, the processes fact sheet subtype models how your applications help you to support your business goals. In contrast to capabilities, they focus on activities. A process in SAP LeanIX is a container, as SAP LeanIX is no dedicated process modeling tool.
Example: Sourcing and Procurement / Create Purchase Order
  * Value stream: Value streams are sequences of activities or steps required for an organization to produce a product or service delivered to a customer (inside-out view of what is needed vs. outside-in that would be represented by customer journeys). Value streams encompass the entire flow of value creation and aim to eliminate waste, reduce inefficiencies, and optimize the overall value delivery process.
Example: Hire to Retire
  * ESG capability (added via optional feature): ESG capabilities are a best-practice representation of relevant ESG (Environmental, social, and corporate governance) areas.
Example: Energy Efficiency Management
Read this detailed documentation on the [Optional Features: ESG Capability Fact Sheet](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to implement sustainable IT transformation using the ESG capability optional feature.") for more information.
